#
# spec file for package strongswan (Version 4.4.0)
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           strongswan
%define         upstream_version 4.4.0
%define         strongswan_docdir %{_docdir}/%{name}
Version:        4.4.0
Release:        6.7.17
License:        GPL v2 or later
Group:          Productivity/Networking/Security
Summary:        StrongSwan -- OpenSource IPsec-based VPN Solution
Url:            http://www.strongswan.org/
PreReq:         gmp grep %insserv_prereq %fillup_prereq
Requires:       iproute2
Provides:       pluto klips ipsec VPN freeswan
Obsoletes:      freeswan
Conflicts:      openswan
AutoReqProv:    on
Source0:        http://download.strongswan.org/strongswan-%{upstream_version}.tar.bz2
Source1:        http://download.strongswan.org/strongswan-%{upstream_version}.tar.bz2.sig
Source2:        %{name}.init.in
Source3:        %{name}-%{version}-rpmlintrc
Patch1:         %{name}_modprobe_syslog.patch
Patch2:         %{name}-4.4.0-snprintf-fix.diff
Patch3:         %{name}-4.4.0-fix_notify_error_range.patch
Patch4:         %{name}-4.4.0-accept_any_ike_minor_version.patch
Patch5:         %{name}-4.4.0-support_ipv6_altname_in_x509_certs.patch
Patch6:         %{name}-4.4.0-allow-integrity-only-and-prf-only-algorithms.patch
Patch7:         %{name}-4.4.0-fix_auth_notify_error_range.patch
Patch8:         %{name}-4.4.0-ts_in_sa.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  bison flex gmp-devel gperf pkg-config
BuildRequires:  libcap-devel
BuildRequires:  openssl-devel
%if 0%{suse_version} >= 1110
BuildRequires:  libgcrypt-devel
%endif
BuildRequires:  openldap2-devel
BuildRequires:  curl-devel

%description
StrongSwan is an OpenSource IPsec-based VPN Solution for Linux

* runs both on Linux 2.4 (KLIPS IPsec) and Linux 2.6 (NETKEY IPsec)
   kernels

* supports both the IKEv1 and IKEv2 (RFC 4306) key exchange
   protocols

* Dynamical IP address and interface update with IKEv2 MOBIKE (RFC
   4555)

* Fast connection startup and periodic update using ipsec starter

* Automatic insertion and deletion of IPsec policy based firewall
   rules

* Strong 3DES, AES, Serpent, Twofish, or Blowfish encryption

* NAT-Traversal via UDP encapsulation and port floating (RFC 3947)

* Static Virtual IPs and IKE Mode Config Pull and Push modes

* XAUTH server and client functionality on top of IKE Main Mode
   authentication

* Dead Peer Detection (DPD, RFC 3706) takes care of dangling tunnels

* Authentication based on X.509 certificates or preshared keys

* Generation of a default self-signed certificate during first
   strongSwan startup

* Retrieval and local caching of Certificate Revocation Lists via
   HTTP or LDAP

* Full support of the Online Certificate Status Protocol (OCSP, RCF
   2560).

* CA management (OCSP and CRL URIs, default LDAP server)

* Powerful IPsec policies based on wildcards or intermediate CAs

* Group policies based on X.509 attribute certificates ( RFC 3281)

* Optional storage of RSA private keys and certificates on a
   smartcard

* Smartcard access via standardized PKCS #11 interface

* PKCS #11 proxy function offering RSA decryption services via whack

* NEW: strongSwan Manager - a graphical management interface for IKEv2



Authors:
--------
    Andreas Steffen
    and others

%package doc
License:        GPL v2 or later
Summary:        strongSwan -- OpenSource IPsec-based VPN Solution
Group:          Productivity/Networking/Security

%description doc
StrongSwan is an OpenSource IPsec-based VPN Solution for Linux

This package provides the StrongSwan documentation.



Authors:
--------
    Andreas Steffen
    and others

%prep
%setup -q -n %{name}-%{upstream_version}
%patch1 -p0
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
sed -e 's|@libexecdir@|%_libexecdir|g'    \
     < $RPM_SOURCE_DIR/strongswan.init.in \
     > strongswan.init

%build
CFLAGS="$RPM_OPT_FLAGS -W -Wall -Wno-pointer-sign -Wno-strict-aliasing"
export RPM_OPT_FLAGS CFLAGS
%{?suse_update_config:%{suse_update_config -f}}
%configure \
	--enable-integrity-test \
	--with-capabilities=libcap \
	--with-resolv-conf=%{_localstatedir}/run/strongswan/resolv.conf \
	--enable-smartcard \
	--with-default-pkcs11=%{_libdir}/opensc-pkcs11.so \
	--enable-cisco-quirks \
	--enable-openssl \
%if 0%{suse_version} >= 1110
	--enable-gcrypt \
%endif
	--enable-ldap \
	--enable-curl
make %{?_smp_mflags:%_smp_mflags}

%install
export RPM_BUILD_ROOT
install -m755 -d              ${RPM_BUILD_ROOT}%{_sbindir}/
install -m755 -d              ${RPM_BUILD_ROOT}%{_sysconfdir}/ipsec.d/
install -m755 -d              ${RPM_BUILD_ROOT}%{_sysconfdir}/init.d/
install -m755 strongswan.init ${RPM_BUILD_ROOT}%{_sysconfdir}/init.d/ipsec
ln -s   %{_sysconfdir}/init.d/ipsec ${RPM_BUILD_ROOT}%{_sbindir}/rcipsec
#
make install DESTDIR="$RPM_BUILD_ROOT"
#
rm -f ${RPM_BUILD_ROOT}%{_sysconfdir}/ipsec.secrets
cat << EOT > ${RPM_BUILD_ROOT}%{_sysconfdir}/ipsec.secrets
#
# ipsec.secrets
#
# This file holds the RSA private keys or the PSK preshared secrets for
# the IKE/IPsec authentication. See the ipsec.secrets(5) manual page.
#
EOT
#
rm -f $RPM_BUILD_ROOT%{_libdir}/lib*.{so,a,la}
find  $RPM_BUILD_ROOT%{_libexecdir}/ipsec \
      -name "*.a" -o -name "*.la" | xargs -r rm -f
#
install -m755 -d ${RPM_BUILD_ROOT}%{strongswan_docdir}/
install -m644 TODO NEWS README COPYING CREDITS \
                 ${RPM_BUILD_ROOT}%{strongswan_docdir}/
install -m755 -d $RPM_BUILD_ROOT%{_localstatedir}/run/strongswan

%post
%{run_ldconfig}
%{fillup_and_insserv ipsec}
test -d %{_localstatedir}/run/strongswan || \
%{__mkdir_p} %{_localstatedir}/run/strongswan

%preun
%{stop_on_removal ipsec}
if test -s %{_sysconfdir}/ipsec.secrets.rpmsave; then
  cp -p --backup=numbered %{_sysconfdir}/ipsec.secrets.rpmsave %{_sysconfdir}/ipsec.secrets.rpmsave.old
fi
if test -s %{_sysconfdir}/ipsec.conf.rpmsave; then
  cp -p --backup=numbered %{_sysconfdir}/ipsec.conf.rpmsave %{_sysconfdir}/ipsec.conf.rpmsave.old
fi

%postun
%{run_ldconfig}
%{insserv_cleanup}

%files
%defattr(-,root,root)
%config(noreplace) %attr(600,root,root) %{_sysconfdir}/ipsec.conf
%config(noreplace) %attr(600,root,root) %{_sysconfdir}/ipsec.secrets
%config(noreplace) %attr(600,root,root) %{_sysconfdir}/strongswan.conf
%dir %{_sysconfdir}/ipsec.d
%dir %{_sysconfdir}/ipsec.d/crls
%dir %{_sysconfdir}/ipsec.d/reqs
%dir %{_sysconfdir}/ipsec.d/certs
%dir %{_sysconfdir}/ipsec.d/acerts
%dir %{_sysconfdir}/ipsec.d/aacerts
%dir %{_sysconfdir}/ipsec.d/cacerts
%dir %{_sysconfdir}/ipsec.d/ocspcerts
%dir %attr(700,root,root) %{_sysconfdir}/ipsec.d/private
%config %{_sysconfdir}/init.d/ipsec
%{_sbindir}/rcipsec
%{_sbindir}/ipsec
%{_libexecdir}/ipsec
%{_libdir}/libhydra.*
%{_libdir}/libcharon.*
%{_libdir}/libstrongswan.*
%{_mandir}/man5/ipsec.conf.5*
%{_mandir}/man5/ipsec.secrets.5*
%{_mandir}/man8/ipsec.8*
%dir %ghost %{_localstatedir}/run/strongswan

%files doc
%defattr(-,root,root)
%dir %{strongswan_docdir}
%{strongswan_docdir}/TODO
%{strongswan_docdir}/NEWS
%{strongswan_docdir}/README
%{strongswan_docdir}/COPYING
%{strongswan_docdir}/CREDITS
%{_mandir}/man3/anyaddr.3*
%{_mandir}/man3/atoaddr.3*
%{_mandir}/man3/atoasr.3*
%{_mandir}/man3/atosa.3*
%{_mandir}/man3/atoul.3*
%{_mandir}/man3/goodmask.3*
%{_mandir}/man3/initaddr.3*
%{_mandir}/man3/initsubnet.3*
%{_mandir}/man3/keyblobtoid.3*
%{_mandir}/man3/portof.3*
%{_mandir}/man3/prng.3*
%{_mandir}/man3/rangetosubnet.3*
%{_mandir}/man3/sameaddr.3*
%{_mandir}/man3/subnetof.3*
%{_mandir}/man3/ttoaddr.3*
%{_mandir}/man3/ttodata.3*
%{_mandir}/man3/ttosa.3*
%{_mandir}/man3/ttoul.3*
%{_mandir}/man8/_copyright.8*
%{_mandir}/man8/_updown.8*
%{_mandir}/man8/_updown_espmark.8*
%{_mandir}/man8/openac.8*
%{_mandir}/man8/pluto.8*
%{_mandir}/man8/scepclient.8*
%{_mandir}/man8/starter.8*

%changelog
* Fri Dec  3 2010 mt@suse.de
- Applied ts_in_sa patch by Jiri Bohac setting negotiated traffic
  selectors (e.g. tcp-only) in SAs for transport mode, that solves
  conformance test failures IKEv2.EN.I.1.1.7.1, IKEv2.EN.R.1.1.7.1
  and IKEv2.EN.R.1.1.7.3.
* Tue Oct 19 2010 mt@suse.de
- Fixed error-type range in parsing of NOTIFY payloads in the
  ike_auth processing as well.
- Applied patches allowing to pass several ipv6ready test cases:
  * Patch by Jiri Bohac fixing error-type range in parsing of
    NOTIFY payloads (RFC 4306, section 3.10.1).
  * Upstream patch to accept IKE packets with any minor version
    in RAW socket.
  * Upstream patch to select subjectAltName address family using
    address length in x509 plugin.
  * Patch by Jiri Bohac discussed upstream, allowing to specify
    different PRF and AUTH algorithms by prepending a prf_ or a
    integrity_ prefix (ike=3des-integrity_md5-prf_sha1-modp1024).
    Note: This patch is applied only to be able to pass ipv6ready
    test cases it and will be replaced with an upstream patch as
    soon as one is available.
- Applied upstream patch fixing snprintf flaws in the strongSwan
  IKE daemons exploitable by unauthenticated attackers using a
  crafted certificate or identification payload (bnc#615915).
- Updated to strongSwan 4.4.0 release -- changes digest since 4.3.4,
  see full changelog at http://download.strongswan.org/CHANGES4.txt:
  * Added IKEv1 and IKEv2 configuration support for the AES-GMAC
  authentication-only ESP cipher. Our aes_gmac kernel patch or a Linux
  2.6.34 kernel is required to make AES-GMAC available via the XFRM
  kernel interface.
  * Added support for Diffie-Hellman groups 22, 23 and 24 to the gmp,
  gcrypt and openssl plugins, usable by both pluto and charon. The new
  proposal keywords are modp1024s160, modp2048s224 and modp2048s256.
  Thanks to Joy Latten from IBM for her contribution. (fate#309537)
  * The ipsec pki --gen and --pub commands now allow the output of
  private and public keys in PEM format using the --outform pem
  command line option.
  * The existing IKEv2 socket implementations have been migrated to
  the socket-default and the socket-raw plugins.  The new
  socket-dynamic plugin binds sockets dynamically to ports configured
  via the left-/rightikeport ipsec.conf connection parameters.
  * The IKEv2 daemon supports RFC 3779 IP address block constraints
  carried as a critical X.509v3 extension in the peer certificate.
  * The Camellia cipher can be used as an IKEv1 encryption algorithm.
  * The IKEv1 and IKEV2 daemons now check certificate path length
  constraints.
  * Added required userland changes for proper SHA256 and SHA384/512
  in ESP that will be introduced with Linux 2.6.33.
  The "sha256"/"sha2_256" keyword now configures the kernel with 128
  bit truncation, not the non-standard 96 bit truncation used by
  previous releases. To use the old 96 bit truncation scheme, the new
  "sha256_96" proposal keyword has been introduced.
  * Fixed IPComp in tunnel mode, stripping out the duplicated outer
  header. This change makes IPcomp tunnel mode connections
  incompatible with previous releases; disable compression on such
  tunnels.
  * Fixed BEET mode connections on recent kernels by installing SAs
  with appropriate traffic selectors, based on a patch by Michael
  Rossberg.
  * Using extensions (such as BEET mode) and crypto algorithms (such
  as twofish, serpent, sha256_96) allocated in the private use space
  now require that we know its meaning, i.e. we are talking to
  strongSwan. Use the new "charon.send_vendor_id" option in
  strongswan.conf to let the remote peer know this is the case.
  * The IKEv1 daemon ignores the Juniper SRX notification type 40001,
  thus allowing interoperability.
- Removed obsolete patches, adopted spec file.
* Wed Sep  2 2009 mt@suse.de
- Applied patch implementing ipsec.secrets "include" directive
  support in charon (http://wiki.strongswan.org/issues/show/82,
  bnc#524799).
* Mon Jul 27 2009 mt@suse.de
- Applied patch for the asn1_length() function checks to complete
  the fixes for the RDN parser DoS vulnerability discovered by
  Orange Labs research team two months ago (bnc#525388).
* Wed Jun 24 2009 mt@suse.de
- Applied fixes for a Denial-of-Service vulnerabilities found by
  Orange Labs vulnerability research team in the parsing of ASN.1
  Relative Distinguished Names (RDNs), GENERALIZEDTIME and UTCTIME
  strings. Malformed X.509 certificate RDNs can cause the pluto
  and charon IKE daemons to crash and restart (bnc#515130).
* Tue Jun  2 2009 mt@suse.de
- Applied fix for a Denial-of-Service vulnerability where receiving
  a malformed IKE_SA_INIT request leaves an incomplete state which
  causes a crash of the IKEv2 charon while dereferencing a NULL
  pointer if a subsequent CREATE_CHILD_SA is received (bnc#507742).
- Applied fix for a Denial-of-Service vulnerability where receiving
  a malformed IKE_AUTH request with either a missing TSi or TSr
  traffic selector payload causes a crash of the IKEv2 charon while
  dereferencing a NULL pointer because the NULL pointer checks of
  TSi and TSr before destruction were erroneously swapped
  (bnc#507742).
* Mon Mar 23 2009 mt@suse.de
- Fix for a Denial-of-Service vulnerability where a DPD R_U_THERE
  or R_U_THERE_ACK NOTIFY message (RFC 3706, Dead Peer Detection)
  received on UDP port 500 or 4500 and not related to an existing
  ISAKMP Security Association causes an immediate crash of the IKEv1
  pluto daemon while dereferencing a NULL state pointer (bnc#487762).
* Fri Oct 17 2008 mt@suse.de
- Replaced changeset backport with officiall DoS patch (bnc#435194).
* Fri Oct 17 2008 mt@suse.de
- Applied fix for addr_in_subnet() extracted from strongswan-4.2.8
  which caused insertion of wrong source routes for destination
  subnets having netwmasks not being a multiple of 8 bits.
  Thanks go to Wolfgang Steudel, TU Ilmenau for reporting this bug.
  (bnc#435200)
* Tue Oct 14 2008 mt@suse.de
- Applied fix for a Denial-of-Service vulnerability where an
  IKE_SA_INIT message with a KE payload containing zeroes only can
  cause a crash of the IKEv2 charon daemon due to a NULL pointer
  returned by the mpz_export() function of the GNU Multi Precision
  (GMP) library. Thanks go to Mu Dynamics Research Labs for making
  us aware of this problem. Changeset r4345 backport (bnc#435194).
* Mon May 19 2008 mt@suse.de
- Applied fix (strongswan_crash_badcfg_reload.dif) to avoid
  a crash after reloading with bad config (bnc#392062).
* Mon Mar 31 2008 mt@suse.de
- Applied fix (strongswan_payload_type_ppc64-changeset_r3431.diff)
  for strongswan IKEv2 failure between i386 and ppc64 caused by an
  incorrect next_payload type declaration (bnc#375425).
* Thu Jan 17 2008 mt@suse.de
- Updated to 4.1.10 final, fixing ordering error in oscp cache,
  fixing IPv6 defaults of the nexthop parameter, adding support
  for new EAP modules [disabled in this build] and obsoleting our
  strongswan_path.dif and strongswan_ipsec_script_msg.dif patches.
- Removed a sed call from init script.
* Sat Dec  8 2007 mt@suse.de
- Updated to 4.1.9 final, including all our patches.
- Changed init script to use ipsec cmd using LSB codes now.
- Added strongswan_path.dif setting a PATH in scripts (updown).
- Added strongswan_ipsec_script_msg.dif for consistent look of
  ipsec script messages.
- Added strongswan_modprobe_syslog.dif redirecting modprobe
  output to syslog.
* Mon Nov 26 2007 mt@suse.de
- Renamed charon plugins to avoid rpm conflicts with existing
  libraries (libstroke). Patch: strongswan-libconflicts.dif
- Added init script. Template file: strongswan.init.in
* Thu Nov 22 2007 mt@suse.de
- Initial, unfinished package
